;; Generated package description from json-mode.el  -*- no-byte-compile: t -*-
(define-package "json-mode" "0.2.0.20201129.42817" "Major mode for editing JSON files" '((emacs "25.1")) :url "https://elpa.gnu.org/packages/json-mode.html" :keywords '("data") :authors '(("Simen Heggestøyl" . "simenheg@gmail.com")) :maintainer '("Simen Heggestøyl" . "simenheg@gmail.com"))
